@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
  *
  * The Totem project hereby grant permission for non-gpl compatible GStreamer
  * plugins to be used and distributed together with GStreamer and Totem. This
@@ -31,7 +31,6 @@
 
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <gconf/gconf-client.h>
 #include <string.h>
 #include <sys/types.h>
 #include <unistd.h>
@@ -43,34 +42,29 @@
 #include "video-utils.h"
 #include "bacon-video-widget.h"
 
-static GObjectClass *parent_class = NULL;
-static void totem_skipto_class_init	(TotemSkiptoClass *class);
-static void totem_skipto_init		(TotemSkipto *ggo);
-static void totem_skipto_finalize	(GObject *object);
+static void totem_skipto_dispose	(GObject *object);
 
 /* Callback functions for GtkBuilder */
-void spin_button_activate_cb (GtkEntry *entry, TotemSkipto *skipto);
-void spin_button_value_changed_cb (GtkSpinButton *spinbutton, TotemSkipto *skipto);
+void time_entry_activate_cb (GtkEntry *entry, TotemSkipto *skipto);
 
 struct TotemSkiptoPrivate {
 	GtkBuilder *xml;
-	GtkWidget *label;
-	GtkWidget *spinbutton;
+	GtkWidget *time_entry;
 	gint64 time;
 	Totem *totem;
 };
 
 TOTEM_PLUGIN_DEFINE_TYPE (TotemSkipto, totem_skipto, GTK_TYPE_DIALOG)
+#define TOTEM_SKIPTO_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), TOTEM_TYPE_SKIPTO, TotemSkiptoPrivate))
 
 static void
 totem_skipto_class_init (TotemSkiptoClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (TotemSkiptoPrivate));
 
-	object_class->finalize = totem_skipto_finalize;
+	object_class->dispose = totem_skipto_dispose;
 }
 
 static void
@@ -79,7 +73,7 @@ totem_skipto_response_cb (GtkDialog *dialog, gint response_id, gpointer data)
 	TotemSkipto *skipto;
 
 	skipto = TOTEM_SKIPTO (dialog);
-	gtk_spin_button_update (GTK_SPIN_BUTTON (skipto->priv->spinbutton));
+	gtk_spin_button_update (GTK_SPIN_BUTTON (skipto->priv->time_entry));
 }
 
 static void
@@ -87,16 +81,22 @@ totem_skipto_init (TotemSkipto *skipto)
 {
 	skipto->priv = G_TYPE_INSTANCE_GET_PRIVATE (skipto, TOTEM_TYPE_SKIPTO, TotemSkiptoPrivate);
 
+	gtk_dialog_set_default_response (GTK_DIALOG (skipto), GTK_RESPONSE_OK);
 	g_signal_connect (skipto, "response",
 				G_CALLBACK (totem_skipto_response_cb), NULL);
 }
 
 static void
-totem_skipto_finalize (GObject *object)
+totem_skipto_dispose (GObject *object)
 {
-	g_return_if_fail (object != NULL);
+	TotemSkiptoPrivate *priv = TOTEM_SKIPTO_GET_PRIVATE (object);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	if (priv->xml != NULL) {
+		g_object_unref (priv->xml);
+		priv->xml = NULL;
+	}
+
+	G_OBJECT_CLASS (totem_skipto_parent_class)->dispose (object);
 }
 
 void
@@ -107,7 +107,7 @@ totem_skipto_update_range (TotemSkipto *skipto, gint64 time)
 	if (time == skipto->priv->time)
 		return;
 
-	gtk_spin_button_set_range (GTK_SPIN_BUTTON (skipto->priv->spinbutton),
+	gtk_spin_button_set_range (GTK_SPIN_BUTTON (skipto->priv->time_entry),
 			0, (gdouble) time / 1000);
 	skipto->priv->time = time;
 }
@@ -119,7 +119,7 @@ totem_skipto_get_range (TotemSkipto *skipto)
 
 	g_return_val_if_fail (TOTEM_IS_SKIPTO (skipto), 0);
 
-	time = gtk_spin_button_get_value (GTK_SPIN_BUTTON (skipto->priv->spinbutton)) * 1000;
+	time = gtk_spin_button_get_value (GTK_SPIN_BUTTON (skipto->priv->time_entry)) * 1000;
 
 	return time;
 }
@@ -138,29 +138,17 @@ totem_skipto_set_current (TotemSkipto *skipto, gint64 time)
 {
 	g_return_if_fail (TOTEM_IS_SKIPTO (skipto));
 
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (skipto->priv->spinbutton),
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (skipto->priv->time_entry),
 			(gdouble) (time / 1000));
 }
 
 void
-spin_button_activate_cb (GtkEntry *entry, TotemSkipto *skipto)
+time_entry_activate_cb (GtkEntry *entry, TotemSkipto *skipto)
 {
 	gtk_dialog_response (GTK_DIALOG (skipto), GTK_RESPONSE_OK);
 }
 
-void
-spin_button_value_changed_cb (GtkSpinButton *spinbutton, TotemSkipto *skipto)
-{
-	int sec;
-	char *str;
-
-	sec = (int) gtk_spin_button_get_value (GTK_SPIN_BUTTON (spinbutton));
-	str = totem_time_to_string_text (sec * 1000);
-	gtk_label_set_text (GTK_LABEL (skipto->priv->label), str);
-	g_free (str);
-}
-
-GtkWidget*
+GtkWidget *
 totem_skipto_new (TotemSkiptoPlugin *plugin)
 {
 	TotemSkipto *skipto;
@@ -177,30 +165,28 @@ totem_skipto_new (TotemSkiptoPlugin *plugin)
 		g_object_unref (skipto);
 		return NULL;
 	}
-	skipto->priv->label = GTK_WIDGET (gtk_builder_get_object
-		(skipto->priv->xml, "tstw_position_label"));
-	skipto->priv->spinbutton = GTK_WIDGET (gtk_builder_get_object
-		(skipto->priv->xml, "tstw_skip_spinbutton"));
+	skipto->priv->time_entry = GTK_WIDGET (gtk_builder_get_object
+		(skipto->priv->xml, "tstw_skip_time_entry"));
 
 	gtk_window_set_title (GTK_WINDOW (skipto), _("Skip to"));
 	gtk_dialog_set_has_separator (GTK_DIALOG (skipto), FALSE);
 	gtk_dialog_add_buttons (GTK_DIALOG (skipto),
-			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-			GTK_STOCK_OK, GTK_RESPONSE_OK,
-			NULL);
+				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+				GTK_STOCK_OK, GTK_RESPONSE_OK,
+				NULL);
 
 	/* Skipto dialog */
 	g_signal_connect (G_OBJECT (skipto), "delete-event",
-			G_CALLBACK (gtk_widget_destroy), skipto);
+			  G_CALLBACK (gtk_widget_destroy), skipto);
 
 	container = GTK_WIDGET (gtk_builder_get_object (skipto->priv->xml,
-			"tstw_skip_vbox"));
+				"tstw_skip_vbox"));
 	gtk_container_set_border_width (GTK_CONTAINER (skipto), 5);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (skipto)->vbox),
-			container,
-			TRUE,       /* expand */
-			TRUE,       /* fill */
-			0);         /* padding */
+			    container,
+			    TRUE,       /* expand */
+			    TRUE,       /* fill */
+			    0);         /* padding */
 
 	gtk_window_set_transient_for (GTK_WINDOW (skipto),
 				      totem_get_main_window (plugin->totem));
